#ifndef ccbqueue_h
#define ccbqueue_h

/*
 * The following enumerators are used to specify what to do if a
 * new message is received when the queue is full.
 */
typedef enum {
  CCB_MQ_DRAIN,    /* Reject this and future messages until the */
                   /*  queue next becomes empty */
  CCB_MQ_WRAP,     /* Overwrite the oldest message in the queue */
  CCB_MQ_DROP      /* Simply reject the message */
} CCBMQFullAction;

typedef struct CCBMessageQueue CCBMessageQueue;

CCBMessageQueue *new_CCBMessageQueue(size_t qwidth, size_t qlength,
				     CCBMQFullAction mode);
CCBMessageQueue *del_CCBMessageQueue(CCBMessageQueue *mq);

/*
 * Add a new message to the queue by copying the first 'size' bytes of
 * 'data' into a new queue bucket, then prepending this bucket to the
 * queue.  The return value is the number of bytes copied from *data
 * into the bucket. If the queue is full, this will be zero. Otherwise
 * it will be the minimum of the value of the 'size' argument of this
 * function, and the qwidth argument of new_CCBMessageQueue().
 */
int ccb_mq_push(CCBMessageQueue *mq, void *data, size_t size);

/*
 * Remove the oldest message from the queue, and return a copy of it
 * in the object pointed to by 'data', which has room for up to 'size'
 * bytes. The return value is the number of bytes copied into *data.
 * This will be zero if the queue is empty, or a positive number <=
 * size, according to the size of the message being removed. Any bytes
 * that won't fit into the return argument are silently discarded.
 */
int ccb_mq_pop(CCBMessageQueue *mq, void *data, size_t size);

/* Empty the queue by throwing away all currently queued messages */

void ccb_mq_purge(CCBMessageQueue *mq);

/* Query how many more messages can be queued */

size_t ccb_mq_space(CCBMessageQueue *mq);

/* Query how many messages are currently queued */

size_t ccb_mq_occupancy(CCBMessageQueue *mq);

/* Is the queue currently closed to give it a chance to drain old messages? */

int ccb_mq_draining(CCBMessageQueue *mq);

#endif
