#ifndef ccbserverpriv_h
#define ccbserverpriv_h

#include "ccbserverlink.h"

/*-----------------------------------------------------------------------*
 * This header file contains functions in ccbserverlink.c which are for  *
 * internal use by ccbserverlink.c and ccbcontrolserver.c. These         *
 * functions are not for use by the calling application, so they are not *
 * included in ccbserverlink.h.                                          *
 *-----------------------------------------------------------------------*/

/*
 * Queue a ping reply for subsequent transmission to the manager over
 * the telemetry link.
 */
int ccb_queue_telem_ping_reply(CCBServerLink *sl, unsigned long seq);

/*
 * Select the set of telemetry streams that are to be sent to the manager.
 */
int ccb_select_streams(CCBServerLink *sl, unsigned streams);

/*
 * Return the general status of the CCB for use in replies to
 * check-status commands.
 */
unsigned ccb_general_status(CCBServerLink *sl);

/*
 * Place the CCB in standby mode.
 */
int ccb_standby(CCBServerLink *sl, unsigned streams);

/*
 * Awaken the CCB from standby mode.
 */
int ccb_awaken(CCBServerLink *sl);

/*
 * Set the period with which the server sub-samples the monitoring
 * packets.
 */
int ccb_monitor_period(CCBServerLink *sl, unsigned short period);

/*
 * Specify which CCB interrupts should be enabled, and which disabled.
 */
int ccb_driver_intr_mask(CCBServerLink *sl, unsigned mask);

/*
 * Set the CCB control-line drive-mask. This can be called at any time.
 */
int ccb_driver_line_mask(CCBServerLink *sl, unsigned mask);

/*
 * Stop the current scan or intra-scan, and be receptive to configuration
 * commands until a new scan or intra-scan is requested.
 */
int ccb_driver_abort_scan(CCBServerLink *sl);

/*
 * Set the configuration parameters of the next scan. This can only be
 * called between calls to ccb_driver_abort_scan() and one of either
 * ccb_driver_stage_scan() or ccb_driver_intra_scan().
 */
int ccb_driver_conf_scan(CCBServerLink *sl, const CCBConfig *cnf);

/*
 * Start a new scan on a given 1PPS-tick. This function can only be called
 * after any previous scan or intra-scan has been aborted by a preceding
 * ccb_driver_abort_scan() call.
 */
int ccb_driver_stage_scan(CCBServerLink *sl, unsigned long scan,
			  unsigned long mjd, unsigned long secs);

/*
 * Start a new intra-scan as soon as possible. This function can only be
 * called after any previous scan or intra-scan has been aborted by a
 * preceding ccb_driver_abort_scan() call.
 */
int ccb_driver_intra_scan(CCBServerLink *sl, unsigned long scan);

/*
 * After first unloading any existing CCB device-driver, load the CCB
 * device driver anew, then reset both the server and the driver to
 * power-on defaults. The CCB is left in standby mode, performing an
 * intra-scan of ID 0.
 */
int ccb_load_driver(CCBServerLink *sl);

/*
 * Unload the CCB device driver.
 */
int ccb_unload_driver(CCBServerLink *sl);

/*
 * Reboot the CCB real-time computer, or simply arrange that it be
 * rebooted ASAP.
 */
int ccb_reboot_rtc(CCBServerLink *sl);

/*
 * Shutdown the CCB real-time computer, or simply arrange that it be
 * shutdown ASAP.
 */
int ccb_shutdown_rtc(CCBServerLink *sl);

/*
 * Set the interval at which historical log messages are forgotten.
 */
int ccb_log_msg_lifetime(CCBServerLink *sl, unsigned long period);

#endif
