#!@PERL@ -w
#-----------------------------------------------------------------------
# Usage:
#  reset_logids files...
#-----------------------------------------------------------------------

use File::Copy;   # Import the file-copying command.

# Check that each of the files specified on the command-line is readable,
# and that they are .c files.

foreach $file (@ARGV) {
  if( ! -f $file || ! -r $file || $file !~ /\.c$/ ) {
    die "$file isn't a readable .c file\n"
  }
}

# Process each of the specified files, writing the filtered version of
# each file temporarily to a temporary file, then replacing the
# original with this temporary file.

foreach $file (@ARGV) {
  open(FILE, "<$file") or die "$!\n";      # Open the original input file.
  $tmpfile = "$file.tmp";
  open(TMP, ">$tmpfile") or die "$!\n";   # Open the temporary output file.

  # Mark the file as unmodified.

  $modified = 0;

  # For each line in the file, replace all LOGID() macros with
  # LOGID(?).

  while($line=<FILE>) {
    if($line =~ s/LOGID\([0-9]+\)/LOGID(?)/g) {
      $modified = 1;
    }

    # Write the possibly modified line to the temporary output file.

    print TMP $line;
  }

  # Did any log statements get modified?

  if($modified) {

    # Backup the original file.

    copy $file, "$file~";

    # Replace the original file with the processed version.

    rename $tmpfile, $file;

  } else {

    unlink $tmpfile;  # Get rid of the temporary file.

  }
}

